import { ScrollView, StyleSheet, Text, TouchableOpacity, View } from 'react-native'
import React, { useState } from 'react'
import { SafeAreaView } from 'react-native-safe-area-context'
import NewscoutTitleHeader from '../../components/molecules/Header/NewscoutTitleHeader'
import colors from '../../constants/colors'
import { TextInput } from 'react-native-paper'
import { horizontalScale, moderateScale, verticalScale } from '../../constants/metrics'
import IonIcon from 'react-native-vector-icons/Ionicons'
import fonts from '../../constants/fonts'
import { navigateToArticle, navigateToListViewPage, useConstructor } from '../../constants/functions'
import { getArticlesBySearch, getCategories } from '../../api/data'
import LoadingScreen from '../../components/organisms/Sections/LoadingScreen'
import { PAGINATE_BY } from '../../api/urls'
import HorizontalNewsCardVariant from '../../components/molecules/Cards/HorizontalNewsCardVariant'


const SearchPage = props => {

  const [isSearching, setSearching] = useState(false)
  const [categories, setCategories] = useState([])
  const [searchText, setSearchText] = useState("")
  const [suggestedNews, setSuggestedNews] = useState([])

  const {
    navigation,
    route
  } = props



  const styles = StyleSheet.create({
    container: {
      backgroundColor: colors().dominant,
      minHeight: '100%',
      maxHeight: 'auto'
    },
    inputTextContainer: {
      backgroundColor: colors().dominant,
      paddingHorizontal: horizontalScale(16),
      paddingBottom: verticalScale(16)
    },
    categoryContainer: {
      padding: verticalScale(16),
      flexDirection: 'row',
      flexWrap: 'wrap',
      gap: moderateScale(16),


    },
    category: {
      height: 170,
      width: 170,
      backgroundColor: colors().secondaryColor,
      borderRadius: moderateScale(8),
      padding: moderateScale(11),
      justifyContent: 'flex-end',
    },
    categoryText: {
      fontFamily: fonts.type.semibold,
      alignSelf: 'flex-end',
      color: colors().white,
      fontSize: moderateScale(14),
      maxWidth: "80%",
      textAlign: 'right'
    }
  })


  const fetchCategories = () => {
    getCategories().then(res => setCategories(res.data.body.results)).catch(err => console.log(err))
  }

  const fetchSuggestions = (search_text) => {
    getArticlesBySearch(search_text)
      .then(res => setSuggestedNews(res.data.body.results.slice(0, PAGINATE_BY)))
      .catch(err => console.log(err))
  }

  useConstructor(() => {
    fetchCategories()
  })

  const onChangeText = (text) => {
    if (text.length > 0) {
      console.warn(text)
      setSearching(true)
      setSearchText(text)
      setSuggestedNews([])
      fetchSuggestions(text)

    } else {
      console.warn(text)
      setSearching(false)
      setSearchText(text)
      setSuggestedNews([])
    }

  }
  return (
    <SafeAreaView style={styles.container}>
      <ScrollView>
        <NewscoutTitleHeader title={"Search"} />

        <View style={styles.inputTextContainer}>
          <TextInput
            editable
            mode='outlined'
            placeholder='Search Text'
            placeholderTextColor={colors().grayShade_300}
            dense
            style={{
              backgroundColor: colors().grayShade_500,
              paddingVertical: moderateScale(8),
            }}
            contentStyle={{
              fontSize: moderateScale(16),
              fontFamily: fonts.type.medium
            }}
            outlineStyle={{
              borderColor: colors().dominant_variant,
              borderRadius: moderateScale(8),
              borderWidth: moderateScale(1)
            }}
            // underlineStyle={{backgroundColor: colors().dominant}}
            left={() => <Text>fdsfdss</Text>}
            right={() => <TouchableOpacity onPress={() => navigateToListViewPage(navigation,'search',searchText)}><IonIcon name="search" color={colors().grayShade_400} size={moderateScale(8)} /></TouchableOpacity>}
            onChangeText={onChangeText}
          />
        </View>
        {
          isSearching === false ?
            <View style={styles.categoryContainer}>
              {categories.map((item) =>
                <TouchableOpacity onPress={() => navigateToListViewPage(navigation, "category", item.heading.name)}>
                  <View style={styles.category}>
                    <Text style={styles.categoryText}>{item.heading.name}</Text>
                  </View>
                </TouchableOpacity>

              )}
            </View>
            : suggestedNews.length <= 0 ?
              <View style={{ alignItems: 'center', justifyContent: 'center', }}><LoadingScreen containerHeight={600} /></View> : <View style={styles.categoryContainer}>
                {suggestedNews.map((item) =>
                  <HorizontalNewsCardVariant
                    onPress={() => navigateToArticle(navigation, item.id, item.slug)}
                    timestamp={item.published_on}
                    headline={item.title}
                    image={{ uri: item.cover_image }}
                    category={item.category}
                    tagline={item.id}
                  />
                )}
              </View>
        }
      </ScrollView>
    </SafeAreaView>
  )
}

export default SearchPage

